==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/offazurespringboot/kotlin/inputs/ErrorArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.offazurespringboot.kotlin.inputs

import com.pulumi.azurenative.offazurespringboot.inputs.ErrorArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Defines the error.
 * @property code The error code.
 * @property id The error ID.
 * @property message The detailed error message.
 * @property possibleCauses The error possible causes.
 * @property recommendedAction The error recommended action
 * @property runAsAccountId The account ID used to login.
 * @property severity The error severity
 * @property summaryMessage The summarized error message.
 * @property updatedTimeStamp Time when this error was last updated.
 */
public data class ErrorArgs(
    public val code: Output<String>? = null,
    public val id: Output<Double>? = null,
    public val message: Output<String>? = null,
    public val possibleCauses: Output<String>? = null,
    public val recommendedAction: Output<String>? = null,
    public val runAsAccountId: Output<String>? = null,
    public val severity: Output<String>? = null,
    public val summaryMessage: Output<String>? = null,
    public val updatedTimeStamp: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.offazurespringboot.inputs.ErrorArgs> {
    override fun toJava(): com.pulumi.azurenative.offazurespringboot.inputs.ErrorArgs =
        com.pulumi.azurenative.offazurespringboot.inputs.ErrorArgs.builder()
            .code(code?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .message(message?.applyValue({ args0 -> args0 }))
            .possibleCauses(possibleCauses?.applyValue({ args0 -> args0 }))
            .recommendedAction(recommendedAction?.applyValue({ args0 -> args0 }))
            .runAsAccountId(runAsAccountId?.applyValue({ args0 -> args0 }))
            .severity(severity?.applyValue({ args0 -> args0 }))
            .summaryMessage(summaryMessage?.applyValue({ args0 -> args0 }))
            .updatedTimeStamp(updatedTimeStamp?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ErrorArgs].
 */
@PulumiTagMarker
public class ErrorArgsBuilder internal constructor() {
    private var code: Output<String>? = null

    private var id: Output<Double>? = null

    private var message: Output<String>? = null

    private var possibleCauses: Output<String>? = null

    private var recommendedAction: Output<String>? = null

    private var runAsAccountId: Output<String>? = null

    private var severity: Output<String>? = null

    private var summaryMessage: Output<String>? = null

    private var updatedTimeStamp: Output<String>? = null

    /**
     * @param value The error code.
     */
    @JvmName("jphrijloqjxmyvyp")
    public suspend fun code(`value`: Output<String>) {
        this.code = value
    }

    /**
     * @param value The error ID.
     */
    @JvmName("aoopwynlyxlkhebr")
    public suspend fun id(`value`: Output<Double>) {
        this.id = value
    }

    /**
     * @param value The detailed error message.
     */
    @JvmName("fcskpfwdrhwibhjj")
    public suspend fun message(`value`: Output<String>) {
        this.message = value
    }

    /**
     * @param value The error possible causes.
     */
    @JvmName("lbpxrlxobhymaidk")
    public suspend fun possibleCauses(`value`: Output<String>) {
        this.possibleCauses = value
    }

    /**
     * @param value The error recommended action
     */
    @JvmName("wdjvmxmmjgwfxymx")
    public suspend fun recommendedAction(`value`: Output<String>) {
        this.recommendedAction = value
    }

    /**
     * @param value The account ID used to login.
     */
    @JvmName("iylpmwstvdembvkb")
    public suspend fun runAsAccountId(`value`: Output<String>) {
        this.runAsAccountId = value
    }

    /**
     * @param value The error severity
     */
    @JvmName("usrbklahxvnpldvg")
    public suspend fun severity(`value`: Output<String>) {
        this.severity = value
    }

    /**
     * @param value The summarized error message.
     */
    @JvmName("njumknfwaywfdlks")
    public suspend fun summaryMessage(`value`: Output<String>) {
        this.summaryMessage = value
    }

    /**
     * @param value Time when this error was last updated.
     */
    @JvmName("arqadftpkbwebfmn")
    public suspend fun updatedTimeStamp(`value`: Output<String>) {
        this.updatedTimeStamp = value
    }

    /**
     * @param value The error code.
     */
    @JvmName("pycwvqdsogdgsqen")
    public suspend fun code(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.code = mapped
    }

    /**
     * @param value The error ID.
     */
    @JvmName("bfjpnklhqmbkfsom")
    public suspend fun id(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The detailed error message.
     */
    @JvmName("hshlxgcpsskppvsn")
    public suspend fun message(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.message = mapped
    }

    /**
     * @param value The error possible causes.
     */
    @JvmName("jkmejerkdsneoinn")
    public suspend fun possibleCauses(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.possibleCauses = mapped
    }

    /**
     * @param value The error recommended action
     */
    @JvmName("yqllhxurenvkvoru")
    public suspend fun recommendedAction(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.recommendedAction = mapped
    }

    /**
     * @param value The account ID used to login.
     */
    @JvmName("kvqhaypxmwyjxgmm")
    public suspend fun runAsAccountId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.runAsAccountId = mapped
    }

    /**
     * @param value The error severity
     */
    @JvmName("ilpujjhbtamveiig")
    public suspend fun severity(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.severity = mapped
    }

    /**
     * @param value The summarized error message.
     */
    @JvmName("lsoinvjpbpsouubc")
    public suspend fun summaryMessage(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.summaryMessage = mapped
    }

    /**
     * @param value Time when this error was last updated.
     */
    @JvmName("isbnftmbmmchcmhx")
    public suspend fun updatedTimeStamp(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.updatedTimeStamp = mapped
    }

    internal fun build(): ErrorArgs = ErrorArgs(
        code = code,
        id = id,
        message = message,
        possibleCauses = possibleCauses,
        recommendedAction = recommendedAction,
        runAsAccountId = runAsAccountId,
        severity = severity,
        summaryMessage = summaryMessage,
        updatedTimeStamp = updatedTimeStamp,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/offazurespringboot/kotlin/inputs/ErrorArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.offazurespringboot.kotlin.inputs

import com.pulumi.azurenative.offazurespringboot.inputs.ErrorArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Defines the error.
 * @property code The error code.
 * @property id The error ID.
 * @property message The detailed error message.
 * @property possibleCauses The error possible causes.
 * @property recommendedAction The error recommended action
 * @property runAsAccountId The account ID used to login.
 * @property severity The error severity
 * @property summaryMessage The summarized error message.
 * @property updatedTimeStamp Time when this error was last updated.
 */
public data class ErrorArgs(
    public val code: Output<String>? = null,
    public val id: Output<Double>? = null,
    public val message: Output<String>? = null,
    public val possibleCauses: Output<String>? = null,
    public val recommendedAction: Output<String>? = null,
    public val runAsAccountId: Output<String>? = null,
    public val severity: Output<String>? = null,
    public val summaryMessage: Output<String>? = null,
    public val updatedTimeStamp: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.offazurespringboot.inputs.ErrorArgs> {
    override fun toJava(): com.pulumi.azurenative.offazurespringboot.inputs.ErrorArgs =
        com.pulumi.azurenative.offazurespringboot.inputs.ErrorArgs.builder()
            .code(code?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .message(message?.applyValue({ args0 -> args0 }))
            .possibleCauses(possibleCauses?.applyValue({ args0 -> args0 }))
            .recommendedAction(recommendedAction?.applyValue({ args0 -> args0 }))
            .runAsAccountId(runAsAccountId?.applyValue({ args0 -> args0 }))
            .severity(severity?.applyValue({ args0 -> args0 }))
            .summaryMessage(summaryMessage?.applyValue({ args0 -> args0 }))
            .updatedTimeStamp(updatedTimeStamp?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ErrorArgs].
 */
@PulumiTagMarker
public class ErrorArgsBuilder internal constructor() {
    private var code: Output<String>? = null

    private var id: Output<Double>? = null

    private var message: Output<String>? = null

    private var possibleCauses: Output<String>? = null

    private var recommendedAction: Output<String>? = null

    private var runAsAccountId: Output<String>? = null

    private var severity: Output<String>? = null

    private var summaryMessage: Output<String>? = null

    private var updatedTimeStamp: Output<String>? = null

    /**
     * @param value The error code.
     */
    @JvmName("frxhjocuhqmjkdkc")
    public suspend fun code(`value`: Output<String>) {
        this.code = value
    }

    /**
     * @param value The error ID.
     */
    @JvmName("rrknscofovoaowag")
    public suspend fun id(`value`: Output<Double>) {
        this.id = value
    }

    /**
     * @param value The detailed error message.
     */
    @JvmName("mnwmbgtdsnpymiqn")
    public suspend fun message(`value`: Output<String>) {
        this.message = value
    }

    /**
     * @param value The error possible causes.
     */
    @JvmName("poqvvxqlbxuicaig")
    public suspend fun possibleCauses(`value`: Output<String>) {
        this.possibleCauses = value
    }

    /**
     * @param value The error recommended action
     */
    @JvmName("mjgvqpdcbhniovwc")
    public suspend fun recommendedAction(`value`: Output<String>) {
        this.recommendedAction = value
    }

    /**
     * @param value The account ID used to login.
     */
    @JvmName("fyppwilwarhnsxmg")
    public suspend fun runAsAccountId(`value`: Output<String>) {
        this.runAsAccountId = value
    }

    /**
     * @param value The error severity
     */
    @JvmName("kcslegtfkstrucal")
    public suspend fun severity(`value`: Output<String>) {
        this.severity = value
    }

    /**
     * @param value The summarized error message.
     */
    @JvmName("pwqktkjuioxldgre")
    public suspend fun summaryMessage(`value`: Output<String>) {
        this.summaryMessage = value
    }

    /**
     * @param value Time when this error was last updated.
     */
    @JvmName("eiqtypnmduffqxek")
    public suspend fun updatedTimeStamp(`value`: Output<String>) {
        this.updatedTimeStamp = value
    }

    /**
     * @param value The error code.
     */
    @JvmName("qqmltblmqpecxtfc")
    public suspend fun code(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.code = mapped
    }

    /**
     * @param value The error ID.
     */
    @JvmName("alpedvslraxnyyjc")
    public suspend fun id(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The detailed error message.
     */
    @JvmName("jufdipxoquonnbdk")
    public suspend fun message(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.message = mapped
    }

    /**
     * @param value The error possible causes.
     */
    @JvmName("acmbadwepegheegs")
    public suspend fun possibleCauses(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.possibleCauses = mapped
    }

    /**
     * @param value The error recommended action
     */
    @JvmName("vvricxvosdalplth")
    public suspend fun recommendedAction(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.recommendedAction = mapped
    }

    /**
     * @param value The account ID used to login.
     */
    @JvmName("kghuuocvibnyglqe")
    public suspend fun runAsAccountId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.runAsAccountId = mapped
    }

    /**
     * @param value The error severity
     */
    @JvmName("dmpdqtaojtrjqatv")
    public suspend fun severity(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.severity = mapped
    }

    /**
     * @param value The summarized error message.
     */
    @JvmName("nqeakiebcmnfijph")
    public suspend fun summaryMessage(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.summaryMessage = mapped
    }

    /**
     * @param value Time when this error was last updated.
     */
    @JvmName("ytoorhlxepwfcrvo")
    public suspend fun updatedTimeStamp(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.updatedTimeStamp = mapped
    }

    internal fun build(): ErrorArgs = ErrorArgs(
        code = code,
        id = id,
        message = message,
        possibleCauses = possibleCauses,
        recommendedAction = recommendedAction,
        runAsAccountId = runAsAccountId,
        severity = severity,
        summaryMessage = summaryMessage,
        updatedTimeStamp = updatedTimeStamp,
    )
}
